@@ -6,9 +6,9 @@ and visualize insights from chatbot message bases.
 
 __author__ = 'squad ROps'
 __email__ = 'anaytics.dar@take.net'
-__version__ = '0.1.0'
+__version__ = '0.2.1'
 __license__ = 'MIT License'
-__credits__ = ['Cecilia Assis', 'Gabriel Salgado', 'Milo Utsch', 'Rogers Damas']
+__credits__ = ['Cecilia Assis', 'Gabriel Salgado', 'Juliana Guamá', 'Milo Utsch', 'Rogers Damas']
 __all__ = ['AiEvaluation']
 
 from .domain import AiEvaluation
